Imports System.IO

Public Class Form1
    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        For Each drive_info As DriveInfo In DriveInfo.GetDrives()
            lstDrives.Items.Add(drive_info.Name)
        Next drive_info
    End Sub

    Private Sub lstDrives_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles lstDrives.SelectedIndexChanged
        Dim drive_info As New DriveInfo(lstDrives.Text)
        Dim results As NtfsInfo = GetNtfsInfo(drive_info.Name)

        txtSerialNumber.Text = results.NTFSVolumeSerialNumber
        txtVersion.Text = results.Version
        txtNumSectors.Text = results.NumberSectors
        txtTotalClusters.Text = results.TotalClusters
        txtFreeClusters.Text = results.FreeClusters
        txtTotalReserved.Text = results.TotalReserved
        txtBytesPerSector.Text = results.BytesPerSector
        txtBytesPerCluster.Text = results.BytesPerCluster
        txtBytesPerFileRecordSegment.Text = results.BytesPerFileRecordSegment
        txtClustersPerFileRecordSegment.Text = results.ClustersPerFileRecordSegment
        txtMftValidDataLength.Text = results.MftValidDataLength
        txtMftStartLcn.Text = results.MftStartLcn
        txtMft2StartLcn.Text = results.Mft2StartLcn
        txtMftZoneStart.Text = results.MftZoneStart
        txtMftZoneEnd.Text = results.MftZoneEnd
    End Sub

    Private Function GetNtfsInfo(ByVal drive_name As String) As NtfsInfo
        Dim text_info As String = ""
        Dim result As New NtfsInfo

        Try
            ' Set start information.
            If drive_name.EndsWith("\") Then drive_name = drive_name.Substring(0, drive_name.Length - 1)
            Dim start_info As New ProcessStartInfo("fsutil", " fsinfo ntfsinfo " & drive_name)
            start_info.UseShellExecute = False
            start_info.CreateNoWindow = True
            start_info.RedirectStandardOutput = True
            start_info.RedirectStandardError = True

            ' Make the process and set its start information.
            Dim proc As New Process()
            proc.StartInfo = start_info

            ' Start the process.
            proc.Start()

            ' Attach to stdout and stderr.
            Dim std_out As StreamReader = proc.StandardOutput()
            Dim std_err As StreamReader = proc.StandardError()

            ' Display the results.
            text_info = std_out.ReadToEnd() & std_err.ReadToEnd()

            ' Clean up.
            std_out.Close()
            std_err.Close()
            proc.Close()

            ' Parse the results.
            text_info = text_info.Replace(vbLf, "").Replace(vbCr & vbCr, vbCr)
            Dim lines() As String = text_info.Split(vbCr)
            For Each one_line As String In lines
                If one_line.Length > 0 Then
                    Dim property_name As String = one_line.Split(":")(0).Replace(" ", "")
                    Dim property_value As String = one_line.Split(":")(1).Replace(" ", "")
                    Select Case property_name
                        Case "NTFSVolumeSerialNumber"
                            result.NTFSVolumeSerialNumber = property_value
                        Case "Version"
                            result.Version = property_value
                        Case "NumberSectors"
                            result.NumberSectors = property_value
                        Case "TotalClusters"
                            result.TotalClusters = property_value
                        Case "FreeClusters"
                            result.FreeClusters = property_value
                        Case "TotalReserved"
                            result.TotalReserved = property_value
                        Case "BytesPerSector"
                            result.BytesPerSector = property_value
                        Case "BytesPerCluster"
                            result.BytesPerCluster = property_value
                        Case "BytesPerFileRecordSegment"
                            result.BytesPerFileRecordSegment = property_value
                        Case "ClustersPerFileRecordSegment"
                            result.ClustersPerFileRecordSegment = property_value
                        Case "MftValidDataLength"
                            result.MftValidDataLength = property_value
                        Case "MftStartLcn"
                            result.MftStartLcn = property_value
                        Case "Mft2StartLcn"
                            result.Mft2StartLcn = property_value
                        Case "MftZoneStart"
                            result.MftZoneStart = property_value
                        Case "MftZoneEnd"
                            result.MftZoneEnd = property_value
                    End Select
                End If
            Next one_line

        Catch ex As Exception
            text_info = "Error getting information" & vbCrLf & vbCrLf & ex.Message
        End Try

        Return result
    End Function
End Class

Public Class NtfsInfo
    Public NTFSVolumeSerialNumber As String = ""
    Public Version As String = ""
    Public NumberSectors As String = ""
    Public TotalClusters As String = ""
    Public FreeClusters As String = ""
    Public TotalReserved As String = ""
    Public BytesPerSector As String = ""
    Public BytesPerCluster As String = ""
    Public BytesPerFileRecordSegment As String = ""
    Public ClustersPerFileRecordSegment As String = ""
    Public MftValidDataLength As String = ""
    Public MftStartLcn As String = ""
    Public Mft2StartLcn As String = ""
    Public MftZoneStart As String = ""
    Public MftZoneEnd As String = ""
End Class